@@ -206,6 +206,12 @@ public:
     */
     xt::xtensor<double, 1> yieldDistanceLeft() const;
 
+    /**
+     * Set time.
+     * \param arg double.
+     */
+    void set_t(double arg);
+
     /**
     Set time step.
 
@@ -348,6 +354,12 @@ public:
     */
     xt::xtensor<double, 1> f_damping() const;
 
+    /**
+     * The time, see set_t().
+     * \return double.
+     */
+    double t() const;
+
     /**
     The time step, see set_dt().
 
@@ -390,7 +402,7 @@ public:
         The number of iterations.
         `0` is returned if there was no plastic activity and the residual was reached.
     */
-    size_t timeStepsUntilEvent(double tol = 1e-5, size_t niter_tol = 10, size_t max_iter = 1000000);
+    size_t timeStepsUntilEvent(double tol = 1e-5, size_t niter_tol = 10, size_t max_iter = 10000000);
 
     /**
     Minimise energy: run timeStep() until a mechanical equilibrium has been reached.
@@ -406,7 +418,7 @@ public:
 
     \return The number of iterations.
     */
-    size_t minimise(double tol = 1e-5, size_t niter_tol = 10, size_t max_iter = 1000000);
+    size_t minimise(double tol = 1e-5, size_t niter_tol = 10, size_t max_iter = 10000000);
 
     /**
     Minimise energy: run timeStep() until a mechanical equilibrium has been reached.
@@ -423,7 +435,7 @@ public:
 
     \return The number of iterations elapsed during an avalanche (in units of dt()).
     */
-    size_t minimise_timeactivity(double tol = 1e-5, size_t niter_tol = 10, size_t max_iter = 1000000);
+    size_t minimise_timeactivity(double tol = 1e-5, size_t niter_tol = 10, size_t max_iter = 10000000);
 
     /**
     Advance the system elastically: the particles and the frame are moved proportionally,
@@ -545,6 +557,7 @@ protected:
     xt::xtensor<double, 1> m_a_n; ///< #a at last time-step.
     std::vector<QPot::Chunked> m_y; ///< Potential energy landscape.
     size_t m_N; ///< See #N.
+    double m_t = 0.0; ///< See #set_t.
     double m_dt = 0.1; ///< See #set_dt.
     double m_eta = 2.0 * std::sqrt(3.0) / 10.0; ///< See #set_eta.
     double m_m = 1.0; ///< See #set_m.
