@@ -282,6 +282,11 @@ inline size_t System::N() const
     return m_N;
 }
 
+inline void System::set_t(double arg)
+{
+    m_t = arg;
+}
+
 inline void System::set_dt(double arg)
 {
     m_dt = arg;
@@ -360,8 +365,8 @@ inline void System::computeForceNeighbours()
     for (size_t p = 1; p < m_N - 1; ++p) {
         m_f_neighbours(p) = m_k_neighbours * (m_x(p - 1) - 2 * m_x(p) + m_x(p + 1));
     }
-    m_f_neighbours(0) = m_k_neighbours * (m_x(m_N - 1) - 2 * m_x(0) + m_x(1));
-    m_f_neighbours(m_N - 1) = m_k_neighbours * (m_x(m_N - 2) - 2 * m_x(m_N - 1) + m_x(0));
+    m_f_neighbours.front() = m_k_neighbours * (m_x.back() - 2 * m_x.front() + m_x(1));
+    m_f_neighbours.back() = m_k_neighbours * (m_x(m_N - 2) - 2 * m_x.back() + m_x.front());
 }
 
 inline void System::computeForceFrame()
@@ -381,6 +386,7 @@ inline void System::computeForce()
 
 inline void System::timeStep()
 {
+    m_t += m_dt;
     xt::noalias(m_v_n) = m_v;
     xt::noalias(m_a_n) = m_a;
 
@@ -419,6 +425,11 @@ inline void System::timeStep()
     }
 }
 
+inline double System::t() const
+{
+    return m_t;
+}
+
 inline double System::dt() const
 {
     return m_dt;
